summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorShulhan <ms@kilabit.info>2021-07-04 23:55:32 +0700
committerShulhan <ms@kilabit.info>2021-07-05 00:02:15 +0700
commit24b08a2c40f0587246fcaaa193e6accfc7ad8197 (patch)
tree719047812b1617e28ec4a95d1f540facc9bc7289
parent6c50a17b71b8a33cdd37a119cbb3157411a221e6 (diff)
downloadpakakeh.go-24b08a2c40f0587246fcaaa193e6accfc7ad8197.tar.xz
lib/ssh: rename the NewClient function to NewClientFromConfig
This is to differentiate it with x/crypto ssh package that have the same function name.
-rw-r--r--lib/ssh/client.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/ssh/client.go b/lib/ssh/client.go
index 1dd4b9ab..60fe25be 100644
--- a/lib/ssh/client.go
+++ b/lib/ssh/client.go
@@ -26,10 +26,10 @@ type Client struct {
}
//
// NewClient create a new SSH connection using predefined
// configuration.
//
-func NewClient(cfg *config.Section) (cl *Client, err error) {
+func NewClientFromConfig(cfg *config.Section) (cl *Client, err error) {
if cfg == nil {
return nil, nil
}
@@ -26,10 +26,10 @@ type Client struct {
}
//
-// NewClient create a new SSH connection using predefined
+// NewClientFromConfig create a new SSH connection using predefined
// configuration.
//